Class: Minitest::Memory::AllocationCounter::Result

Inherits:
Struct
  • Object
show all
Defined in:
lib/minitest/memory.rb

Overview

Holds allocation counting results: allocated maps matched classes to Allocations, ignored maps unmatched classes, and total is the aggregate Allocation across all objects.

Instance Attribute Summary collapse

Instance Attribute Details

#allocated ⇒ Object

Returns the value of attribute allocated

Returns:

  • (Object) —

    the current value of allocated



24
25
26
# File 'lib/minitest/memory.rb', line 24

def allocated
  @allocated
end

#ignored ⇒ Object

Returns the value of attribute ignored

Returns:

  • (Object) —

    the current value of ignored



24
25
26
# File 'lib/minitest/memory.rb', line 24

def ignored
  @ignored
end

#total ⇒ Object

Returns the value of attribute total

Returns:

  • (Object) —

    the current value of total



24
25
26
# File 'lib/minitest/memory.rb', line 24

def total
  @total
end